Package: PanomiR
Title: Detection of miRNAs that regulate interacting groups of pathways
Version: 1.15.0
Authors@R: c(
    person("Pourya", "Naderi", email = "pouryany@gmail.com",
           role = c("aut", "cre")),
    person("Yue Yang (Alan)", "Teo", email = "yueyang.teo@epfl.ch",
           role = c("aut")),
    person("Ilya", "Sytchev", email = "isytchev@hsph.harvard.edu",
           role = c("aut")),
    person("Winston", "Hide", email = "whide@bidmc.harvard.edu",
           role = c("aut")))
Description: PanomiR is a package to detect miRNAs that target groups of
    pathways from gene expression data. This package provides functionality 
    for generating pathway activity profiles, determining differentially
    activated pathways between user-specified conditions, determining 
    clusters of pathways via the PCxN package, and generating miRNAs targeting
    clusters of pathways. These function can be used separately or sequentially
    to analyze RNA-Seq data.
License: MIT + file LICENSE
Encoding: UTF-8
RoxygenNote: 7.1.2
Suggests: testthat (>= 3.0.0), BiocStyle, knitr, rmarkdown
Config/testthat/edition: 3
biocViews: GeneExpression, GeneSetEnrichment, GeneTarget, miRNA,
        Pathways
Imports: clusterProfiler, dplyr, forcats, GSEABase, igraph, limma,
        metap, org.Hs.eg.db, parallel, preprocessCore, RColorBrewer,
        rlang, tibble, withr, utils
Depends: R (>= 4.2.0)
URL: https://github.com/pouryany/PanomiR
BugReports: https://github.com/pouryany/PanomiR/issues
VignetteBuilder: knitr
git_url: https://git.bioconductor.org/packages/PanomiR
git_branch: devel
git_last_commit: eb18fe4
git_last_commit_date: 2025-10-29
Repository: Bioconductor 3.23
Date/Publication: 2025-10-31
NeedsCompilation: no
Packaged: 2025-10-31 23:21:21 UTC; biocbuild
Author: Pourya Naderi [aut, cre],
  Yue Yang (Alan) Teo [aut],
  Ilya Sytchev [aut],
  Winston Hide [aut]
Maintainer: Pourya Naderi <pouryany@gmail.com>
