# Generated by roxygen2: do not edit by hand

export(clusterPlot)
export(differentialPathwayAnalysis)
export(getDesignMatrix)
export(linColumnFinder)
export(mappingPathwaysClusters)
export(miRNAPathwayEnrichment)
export(pathwayGeneTab)
export(pathwaySummary)
export(prioritizeMicroRNA)
export(reportEnrichment)
export(tableFromGSC)
